import os
from django.contrib.auth import get_user_model
from rest_framework import serializers
from .models import Employee, EmployeeField, Badge, BadgeField, BadgeStat, UpdateBadge


User = get_user_model()


class UserSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        fields = ( "id", "username", "first_name", "last_name" )


class BadgeSerializer(serializers.ModelSerializer):
    class Meta:
        model = Badge
        fields = "__all__"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        if os.getenv("MIGRATING", "True"):
            return

        allowed = set([ r.field for r in BadgeField.objects.all() ])
        existing = set(self.fields.keys())
        for f in existing - allowed:
            self.fields.pop(f)


class EmployeeSerializer(serializers.ModelSerializer):
    badges = BadgeSerializer(many=True)

    class Meta:
        model = Employee
        fields = "__all__"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        allowed = set([ r.field for r in EmployeeField.objects.all() ])
        existing = set(self.fields.keys())
        for f in existing - allowed:
            self.fields.pop(f)


class BadgeStatSerializer(serializers.ModelSerializer):
    class Meta:
        model = BadgeStat
        fields = "__all__"


class UpdateBadgeSerializer(serializers.ModelSerializer):
    class Meta:
        model = UpdateBadge
        fields = "__all__"